@@ -16,12 +16,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import functools
 import os
 
 from pyroute2.netlink import exceptions as netlink_exceptions
 
 from neutron.agent.linux import ip_lib
+from neutron.agent.linux import utils as linux_utils
 from neutron.privileged.agent.linux import ip_lib as priv_ip_lib
 
 # NOTE(toabctl): Don't use /sys/devices/virtual/net here because not all tap
@@ -34,15 +36,17 @@ BRIDGE_PATH_FOR_DEVICE = BRIDGE_PORT_FS_FOR_DEVICE + '/bridge'
 
 
 def catch_exceptions(function):
-    """Catch bridge command exceptions and mimic $? output"""
+    """Catch bridge command exceptions
 
+    Returns True if succeeds and False if fails
+    """
     @functools.wraps(function)
     def decorated_function(self, *args, **kwargs):
         try:
             function(self, *args, **kwargs)
-            return 0
+            return True
         except (RuntimeError, OSError, netlink_exceptions.NetlinkError):
-            return 1
+            return False
 
     return decorated_function
 
@@ -50,15 +54,14 @@ def catch_exceptions(function):
 def is_bridged_interface(interface):
     if not interface:
         return False
-    else:
-        return os.path.exists(BRIDGE_PORT_FS_FOR_DEVICE % interface)
+    return os.path.exists(BRIDGE_PORT_FS_FOR_DEVICE % interface)
 
 
 def get_interface_ifindex(interface):
     try:
-        with open(os.path.join(BRIDGE_FS, interface, 'ifindex'), 'r') as fh:
+        with open(os.path.join(BRIDGE_FS, interface, 'ifindex')) as fh:
             return int(fh.read().strip())
-    except (IOError, ValueError):
+    except (OSError, ValueError):
         pass
 
 
@@ -83,9 +86,8 @@ class BridgeDevice(ip_lib.IPDevice):
             path = os.readlink(BRIDGE_PATH_FOR_DEVICE % interface)
         except OSError:
             return None
-        else:
-            name = path.rpartition('/')[-1]
-            return cls(name)
+        name = path.rpartition('/')[-1]
+        return cls(name)
 
     def delbr(self):
         return self.link.delete()
@@ -125,40 +127,67 @@ class BridgeDevice(ip_lib.IPDevice):
             return []
 
 
-class FdbInterface(object):
-    """provide basic functionality to edit the FDB table"""
+class FdbInterface:
+    """Provide basic functionality to edit the FDB table"""
 
     @staticmethod
-    def _execute_bridge(cmd, namespace, **kwargs):
-        ip_wrapper = ip_lib.IPWrapper(namespace)
-        return ip_wrapper.netns.execute(cmd, run_as_root=True, **kwargs)
+    @catch_exceptions
+    def add(mac, dev, dst_ip=None, namespace=None, **kwargs):
+        priv_ip_lib.add_bridge_fdb(mac, dev, dst_ip=dst_ip,
+                                   namespace=namespace, **kwargs)
 
-    @classmethod
-    def _cmd(cls, op, mac, dev, ip_dst, namespace, **kwargs):
-        cmd = ['bridge', 'fdb', op, mac, 'dev', dev]
-        if ip_dst is not None:
-            cmd += ['dst', ip_dst]
-        cls._execute_bridge(cmd, namespace, **kwargs)
+    @staticmethod
+    @catch_exceptions
+    def append(mac, dev, dst_ip=None, namespace=None, **kwargs):
+        priv_ip_lib.append_bridge_fdb(mac, dev, dst_ip=dst_ip,
+                                      namespace=namespace, **kwargs)
 
-    @classmethod
-    def add(cls, mac, dev, ip_dst=None, namespace=None, **kwargs):
-        return cls._cmd('add', mac, dev, ip_dst, namespace, **kwargs)
+    @staticmethod
+    @catch_exceptions
+    def replace(mac, dev, dst_ip=None, namespace=None, **kwargs):
+        try:
+            priv_ip_lib.delete_bridge_fdb(mac, dev, namespace=namespace,
+                                          **kwargs)
+        except (RuntimeError, OSError, netlink_exceptions.NetlinkError):
+            pass
+        priv_ip_lib.add_bridge_fdb(mac, dev, dst_ip=dst_ip,
+                                   namespace=namespace, **kwargs)
 
-    @classmethod
-    def append(cls, mac, dev, ip_dst=None, namespace=None, **kwargs):
-        return cls._cmd('append', mac, dev, ip_dst, namespace, **kwargs)
+    @staticmethod
+    @catch_exceptions
+    def delete(mac, dev, dst_ip=None, namespace=None, **kwargs):
+        priv_ip_lib.delete_bridge_fdb(mac, dev, dst_ip=dst_ip,
+                                      namespace=namespace, **kwargs)
 
-    @classmethod
-    def replace(cls, mac, dev, ip_dst=None, namespace=None, **kwargs):
-        return cls._cmd('replace', mac, dev, ip_dst, namespace, **kwargs)
+    @staticmethod
+    def show(dev=None, namespace=None, **kwargs):
+        """List the FDB entries in a namespace
 
-    @classmethod
-    def delete(cls, mac, dev, ip_dst=None, namespace=None, **kwargs):
-        return cls._cmd('delete', mac, dev, ip_dst, namespace, **kwargs)
+        :parameter dev: device name to filter the query
+        :parameter namespace: namespace name
+        :returns: a dictionary with the device names and the list of entries
+                  per device.
+        """
 
-    @classmethod
-    def show(cls, dev=None, namespace=None, **kwargs):
-        cmd = ['bridge', 'fdb', 'show']
-        if dev:
-            cmd += ['dev', dev]
-        return cls._execute_bridge(cmd, namespace, **kwargs)
+        def find_device_name(ifindex, devices):
+            for device in (device for device in devices if
+                           device['index'] == ifindex):
+                return device['name']
+
+        ret = collections.defaultdict(list)
+        fdbs = priv_ip_lib.list_bridge_fdb(namespace=namespace, **kwargs)
+        devices = ip_lib.get_devices_info(namespace)
+        for fdb in fdbs:
+            name = find_device_name(fdb['ifindex'], devices)
+            if dev and dev != name:
+                continue
+
+            master = find_device_name(linux_utils.get_attr(fdb, 'NDA_MASTER'),
+                                      devices)
+            fdb_info = {'mac': linux_utils.get_attr(fdb, 'NDA_LLADDR'),
+                        'master': master,
+                        'vlan': linux_utils.get_attr(fdb, 'NDA_VLAN'),
+                        'dst_ip': linux_utils.get_attr(fdb, 'NDA_DST')}
+            ret[name].append(fdb_info)
+
+        return ret
