@@ -13,8 +13,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import typing
-
 from oslo_utils import timeutils
 
 from neutron.common import utils
@@ -51,7 +49,7 @@ def get_start_time(default=None, current_time=False):
         return default
 
 
-def get_api_worker_id() -> typing.Union[int, None]:
+def get_api_worker_id() -> int | None:
     """Return the worker ID number provided by uWSGI"""
     try:
         # pylint: disable=import-outside-toplevel
