@@ -16,12 +16,12 @@ from oslo_config import cfg
 from neutron._i18n import _
 
 EXPERIMENTAL_CFG_GROUP = 'experimental'
-EXPERIMENTAL_LINUXBRIDGE = 'linuxbridge'
+EXPERIMENTAL_IPV6_PD = 'ipv6_pd_enabled'
 experimental_opts = [
-    cfg.BoolOpt(EXPERIMENTAL_LINUXBRIDGE,
+    cfg.BoolOpt(EXPERIMENTAL_IPV6_PD,
                 default=False,
-                help=_('Enable execution of the experimental Linuxbridge '
-                       'agent.')),
+                help=_('Enable execution of the experimental IPv6 Prefix '
+                       'Delegation functionality in the plugin.')),
 ]
 
 
