@@ -13,9 +13,10 @@
 #    under the License.
 #
 
-from alembic import op
 import sqlalchemy as sa
 
+from neutron.db import migration
+
 
 # Add qinq column to the Network table
 #
@@ -27,9 +28,12 @@ import sqlalchemy as sa
 revision = 'ad80a9f07c5c'
 down_revision = '5bcb7b31ec7d'
 
+# milestone identifier, used by neutron-db-manage
+neutron_milestone = [migration.RELEASE_2025_1]
+
 
 def upgrade():
-    op.add_column(
+    migration.add_column_if_not_exists(
         'networks',
         sa.Column('qinq', sa.Boolean(), server_default=None)
     )
