@@ -11,10 +11,9 @@
 #    under the License.
 
 from neutron_lib.db import model_base
+from neutron_lib.db import standard_attr
 import sqlalchemy as sa
 
-from neutron.db import standard_attr
-
 
 class ProvisioningBlock(model_base.BASEV2):
     # the standard attr id of the thing we want to block
