@@ -22,7 +22,7 @@ class PortUplinkStatusPropagation(model_base.BASEV2):
 
     port_id = sa.Column(sa.String(36),
                         sa.ForeignKey('ports.id', ondelete="CASCADE"),
-                        primary_key=True, index=True)
+                        primary_key=True)
     propagate_uplink_status = sa.Column(sa.Boolean(), nullable=False,
                                         server_default=sa.sql.true())
     port = orm.relationship(
