@@ -87,7 +87,7 @@ class IPAllocationPool(model_base.BASEV2, model_base.HasId):
     last_ip = sa.Column(sa.String(64), nullable=False)
 
     def __repr__(self):
-        return "{} - {}".format(self.first_ip, self.last_ip)
+        return f"{self.first_ip} - {self.last_ip}"
 
 
 class IPAllocation(model_base.BASEV2):
