@@ -31,7 +31,7 @@ LOG = logging.getLogger(__name__)
 MAX_RETIES = 1000
 
 
-class MeterIDGenerator(object):
+class MeterIDGenerator:
     # This cache will be:
     #  PORT_METER_ID = {"port_id_1_ingress": 1,
     #                   "port_id_1_egress: 2,
@@ -41,7 +41,7 @@ class MeterIDGenerator(object):
     def __new__(cls, *args, **kwargs):
         # make it a singleton
         if not hasattr(cls, '_instance'):
-            cls._instance = super(MeterIDGenerator, cls).__new__(cls)
+            cls._instance = super().__new__(cls)
             cls.PORT_METER_ID = {}
         return cls._instance
 
@@ -75,7 +75,7 @@ class MeterIDGenerator(object):
         self.PORT_METER_ID[key] = meter_id
 
 
-class MeterRuleManager(object):
+class MeterRuleManager:
 
     def __init__(self, br_int, type_=comm_consts.METER_FLAG_PPS):
         self.br_int = br_int
@@ -103,7 +103,7 @@ class MeterRuleManager(object):
                 break
 
     def get_data_key(self, port_id, direction):
-        return "%s_%s_%s" % (self.rule_type, port_id, direction)
+        return "{}_{}_{}".format(self.rule_type, port_id, direction)
 
     def load_port_meter_id(self, port_name, port_id, direction):
         key = self.get_data_key(port_id, direction)
@@ -150,7 +150,7 @@ class MeterRuleManager(object):
         return self.PORT_INFO_EGRESS.pop(port_id, (None, None, None))
 
 
-class OVSMeterQoSDriver(object):
+class OVSMeterQoSDriver:
 
     SUPPORT_METER = None
 
@@ -287,6 +287,24 @@ class OVSMeterQoSDriver(object):
                                       self.meter_cache_pps,
                                       type_=comm_consts.METER_FLAG_PPS)
 
+    def _delete_meter_bandwidth_rate_limit(self, port_id, direction):
+        self._delete_meter_rate_limit(port_id, direction, self.meter_cache_bps,
+                                      type_=comm_consts.METER_FLAG_BPS)
+
+    def _update_meter_bandwidth_rate_limit(self, vif_port, rule, direction):
+        max_kbps = rule.max_kbps
+        max_burst_kbps = rule.max_burst_kbps or 0
+        LOG.debug("Update port %(port)s %(direction)s meter bandwidth limit "
+                  "with rate: %(rate)s, burst: %(burst)s",
+                  {"port": vif_port.vif_id,
+                   "direction": direction,
+                   "rate": max_kbps,
+                   "burst": max_burst_kbps})
+        self._update_meter_rate_limit(vif_port, direction,
+                                      max_kbps, max_burst_kbps,
+                                      self.meter_cache_bps,
+                                      type_=comm_consts.METER_FLAG_BPS)
+
 
 class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
                         OVSMeterQoSDriver):
@@ -294,7 +312,7 @@ class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
     SUPPORTED_RULES = driver.SUPPORTED_RULES
 
     def __init__(self):
-        super(QosOVSAgentDriver, self).__init__()
+        super().__init__()
         self.br_int_name = cfg.CONF.OVS.integration_bridge
         self.br_int = None
         self.agent_api = None
@@ -320,6 +338,8 @@ class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
         self.cookie = self.br_int.default_cookie
         self._qos_bandwidth_initialize()
         self.meter_cache_pps = MeterRuleManager(self.br_int)
+        self.meter_cache_bps = MeterRuleManager(
+            self.br_int, type_=comm_consts.METER_FLAG_BPS)
 
     def create_bandwidth_limit(self, port, rule):
         self.update_bandwidth_limit(port, rule)
@@ -353,7 +373,12 @@ class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
                       port_id)
             return
         vif_port = vif_port or port.get('vif_port')
-        self.br_int.delete_egress_bw_limit_for_port(vif_port.port_name)
+
+        if cfg.CONF.OVS.qos_meter_bandwidth:
+            self._delete_meter_bandwidth_rate_limit(
+                port_id, direction=constants.EGRESS_DIRECTION)
+        else:
+            self.br_int.delete_egress_bw_limit_for_port(vif_port.port_name)
 
     def delete_bandwidth_limit_ingress(self, port):
         port_id = port.get('port_id')
@@ -368,7 +393,12 @@ class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
                       port_id)
             return
         vif_port = vif_port or port.get('vif_port')
-        self.br_int.delete_ingress_bw_limit_for_port(vif_port.port_name)
+
+        if cfg.CONF.OVS.qos_meter_bandwidth:
+            self._delete_meter_bandwidth_rate_limit(
+                port_id, direction=constants.INGRESS_DIRECTION)
+        else:
+            self.br_int.delete_ingress_bw_limit_for_port(vif_port.port_name)
 
     def create_dscp_marking(self, port, rule):
         self.update_dscp_marking(port, rule)
@@ -408,20 +438,28 @@ class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
         # ovs accepts only integer values of burst:
         max_burst_kbps = int(self._get_egress_burst_value(rule))
 
-        self.br_int.create_egress_bw_limit_for_port(vif_port.port_name,
-                                                    max_kbps,
-                                                    max_burst_kbps)
+        if cfg.CONF.OVS.qos_meter_bandwidth:
+            self._update_meter_bandwidth_rate_limit(
+                vif_port, rule, direction=constants.EGRESS_DIRECTION)
+        else:
+            self.br_int.create_egress_bw_limit_for_port(vif_port.port_name,
+                                                        max_kbps,
+                                                        max_burst_kbps)
 
     def _update_ingress_bandwidth_limit(self, vif_port, rule):
         port_name = vif_port.port_name
         max_kbps = rule.max_kbps or 0
         max_burst_kbps = rule.max_burst_kbps or 0
 
-        self.br_int.update_ingress_bw_limit_for_port(
-            port_name,
-            max_kbps,
-            max_burst_kbps
-        )
+        if cfg.CONF.OVS.qos_meter_bandwidth:
+            self._update_meter_bandwidth_rate_limit(
+                vif_port, rule, direction=constants.INGRESS_DIRECTION)
+        else:
+            self.br_int.update_ingress_bw_limit_for_port(
+                port_name,
+                max_kbps,
+                max_burst_kbps
+            )
 
     def create_minimum_bandwidth(self, port, rule):
         self.update_minimum_bandwidth(port, rule)
@@ -433,7 +471,7 @@ class QosOVSAgentDriver(qos.QosLinuxAgentDriver,
                       'vif_port was not found. It seems that port is already '
                       'deleted', port.get('port_id'))
             return
-        elif not port.get('physical_network'):
+        if not port.get('physical_network'):
             LOG.debug('update_minimum_bandwidth was received for port %s but '
                       'has no physical network associated',
                       port.get('port_id'))
