@@ -66,7 +66,7 @@ class OvnNbTransaction(idl_trans.Transaction):
         # NOTE(lucasagomes): The bump_nb_cfg parameter is only used by
         # the agents health status check
         self.bump_nb_cfg = kwargs.pop('bump_nb_cfg', False)
-        super(OvnNbTransaction, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def pre_commit(self, txn):
         if not self.bump_nb_cfg:
@@ -80,7 +80,7 @@ def add_keepalives(fn):
         error, sock = fn(*args, **kwargs)
         try:
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
-        except socket.error as e:
+        except OSError as e:
             sock.close()
             return socket_util.get_exception_errno(e), None
         return error, sock
@@ -121,7 +121,7 @@ class Backend(ovs_idl.Backend):
 
     def __init__(self, connection):
         self.ovsdb_connection = connection
-        super(Backend, self).__init__(connection)
+        super().__init__(connection)
 
     def start_connection(self, connection):
         try:
@@ -234,9 +234,6 @@ def get_ovn_idls(driver, trigger):
 
 
 class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
-    def __init__(self, connection):
-        super(OvsdbNbOvnIdl, self).__init__(connection)
-
     @n_utils.classproperty
     def connection_string(cls):
         return cfg.get_ovn_nb_connection()
@@ -271,17 +268,24 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         """
         revision_mismatch_raise = kwargs.pop('revision_mismatch_raise', False)
         try:
-            with super(OvsdbNbOvnIdl, self).transaction(*args, **kwargs) as t:
+            with super().transaction(*args, **kwargs) as t:
                 yield t
         except ovn_exc.RevisionConflict as e:
             LOG.info('Transaction aborted. Reason: %s', e)
             if revision_mismatch_raise:
                 raise e
 
+    def ls_add(self, switch=None, may_exist=False, network_id=None, **columns):
+        if network_id is None:
+            return super().ls_add(switch, may_exist, **columns)
+        return cmd.AddNetworkCommand(self, network_id, may_exist=may_exist,
+                                     **columns)
+
     def create_lswitch_port(self, lport_name, lswitch_name, may_exist=True,
-                            **columns):
+                            network_id=None, **columns):
         return cmd.AddLSwitchPortCommand(self, lport_name, lswitch_name,
-                                         may_exist, **columns)
+                                         may_exist, network_id=network_id,
+                                         **columns)
 
     def set_lswitch_port(self, lport_name, external_ids_update=None,
                          if_exists=True, **columns):
@@ -297,9 +301,7 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         if lport_name is not None:
             return cmd.DelLSwitchPortCommand(self, lport_name,
                                              lswitch_name, if_exists)
-        else:
-            raise RuntimeError(_("Currently only supports "
-                                 "delete by lport-name"))
+        raise RuntimeError(_("Currently only supports delete by lport-name"))
 
     def get_all_logical_switches_with_ports(self):
         result = []
@@ -362,13 +364,31 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
                 elif nat.type == 'snat':
                     snat.append(columns)
 
-            result.append({'name': lrouter.name.replace('neutron-', ''),
+            result.append({'name': utils.get_neutron_name(lrouter.name),
                            'static_routes': sroutes,
                            'ports': lrports,
                            'snats': snat,
                            'dnat_and_snats': dnat_and_snats})
         return result
 
+    def get_all_logical_routers_static_routes(self):
+        """Get static routes associated with all logical Routers
+
+        @return: list of dict, each dict has key-value:
+                 - 'name': string router_id in neutron.
+                 - 'static_routes': list of static routes rows.
+        """
+        result = []
+        for lrouter in self._tables['Logical_Router'].rows.values():
+            if (ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY not in
+                    lrouter.external_ids):
+                continue
+            result.append({'name': utils.get_neutron_name(lrouter.name),
+                           'static_routes': getattr(lrouter, 'static_routes',
+                                                    [])})
+
+        return result
+
     def get_acl_by_id(self, acl_id):
         try:
             return self.lookup('ACL', uuid.UUID(acl_id))
@@ -428,6 +448,11 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         return cmd.UpdateLRouterCommand(self, name,
                                         if_exists, **columns)
 
+    # This method overrides the parent class ``nb_impl_idl.OvnNbApiIdlImpl``
+    # implementation.
+    def lr_del(self, router, if_exists=False):
+        return cmd.LrDelCommand(self, router, if_exists=if_exists)
+
     def add_lrouter_port(self, name, lrouter, may_exist=False, **columns):
         return cmd.AddLRouterPortCommand(self, name, lrouter,
                                          may_exist, **columns)
@@ -469,9 +494,11 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         return cmd.AddStaticRouteCommand(self, lrouter, maintain_bfd,
                                          **columns)
 
-    def delete_static_route(self, lrouter, ip_prefix, nexthop, if_exists=True):
-        return cmd.DelStaticRouteCommand(self, lrouter, ip_prefix, nexthop,
-                                         if_exists)
+    def delete_static_routes(self, lrouter, routes, if_exists=True):
+        return cmd.DelStaticRoutesCommand(self, lrouter, routes, if_exists)
+
+    def set_static_route(self, sroute, **columns):
+        return cmd.SetStaticRouteCommand(self, sroute, **columns)
 
     def _get_logical_router_port_gateway_chassis(self, lrp, priorities=None):
         """Get the list of chassis hosting this gateway port.
@@ -500,6 +527,30 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         # make sure that chassis are sorted by priority
         return sorted(chassis, reverse=True, key=lambda x: x[1])
 
+    @staticmethod
+    def _get_logical_router_port_ha_chassis_group(lrp, priorities=None):
+        """Get the list of chassis hosting this gateway port.
+
+        @param   lrp: logical router port
+        @type    lrp: Logical_Router_Port row
+        @param   priorities: a list of gateway chassis priorities to search for
+        @type    priorities: list of int
+        @return: List of tuples (chassis_name, priority) sorted by priority. If
+                 ``priorities`` is set then only chassis matching of these
+                 priorities are returned.
+        """
+        chassis = []
+        hcg = getattr(lrp, 'ha_chassis_group', None)
+        if not hcg:
+            return chassis
+
+        for hc in hcg[0].ha_chassis:
+            if priorities is not None and hc.priority not in priorities:
+                continue
+            chassis.append((hc.chassis_name, hc.priority))
+        # Make sure that chassis are sorted by priority (highest prio first)
+        return sorted(chassis, reverse=True, key=lambda x: x[1])
+
     def get_all_chassis_gateway_bindings(self,
                                          chassis_candidate_list=None,
                                          priorities=None):
@@ -533,10 +584,9 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
                           default=None)
         if not lrp:
             return []
-        router_id = lrp.external_ids.get(
+        router_name = lrp.external_ids.get(
             ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY, "")
-        lrouter = self.lookup('Logical_Router', utils.ovn_name(router_id),
-                              default=None)
+        lrouter = self.lookup('Logical_Router', router_name, default=None)
         if not lrouter:
             return []
         az_string = lrouter.external_ids.get(
@@ -562,7 +612,7 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
             if not physnet:
                 continue
 
-            lrp_name = '%s%s' % (ovn_const.LRP_PREFIX, port)
+            lrp_name = f'{ovn_const.LRP_PREFIX}{port}'
             original_state = self.get_gateway_chassis_binding(lrp_name)
             az_hints = self.get_gateway_chassis_az_hints(lrp_name)
             # Filter out chassis that lost physnet, the cms option,
@@ -762,6 +812,13 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         result = fip.execute(check_error=True)
         return result[0] if result else None
 
+    def get_floatingips(self):
+        cmd = self.db_find('NAT',
+            ('external_ids', '!=', {ovn_const.OVN_FIP_EXT_ID_KEY: ''}),
+            ('type', '=', 'dnat_and_snat')
+        )
+        return cmd.execute(check_error=True)
+
     def check_revision_number(self, name, resource, resource_type,
                               if_exists=True):
         return cmd.CheckRevisionNumberCommand(
@@ -792,7 +849,7 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         for lrp in getattr(lr, 'ports', []):
             lrp_ext_ids = getattr(lrp, 'external_ids', {})
             if (r_name not in lrp_ext_ids or
-                    utils.ovn_name(lrp_ext_ids[r_name]) != lr.name or
+                    lrp_ext_ids[r_name] != lr.name or
                     not strutils.bool_from_string(lrp_ext_ids.get(is_gw))):
                 continue
 
@@ -886,11 +943,14 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         return cmd.SetLRouterMacAgeLimitCommand(
             self, router, cfg.get_ovn_mac_binding_age_threshold())
 
+    def ha_chassis_group_with_hc_add(self, name, chassis_priority,
+                                     may_exist=False, **columns):
+        return cmd.HAChassisGroupWithHCAddCommand(
+            self, name, chassis_priority, may_exist=may_exist,
+            **columns)
+
 
 class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
-    def __init__(self, connection):
-        super(OvsdbSbOvnIdl, self).__init__(connection)
-
     @n_utils.classproperty
     def connection_string(cls):
         return cfg.get_ovn_sb_connection()
@@ -962,10 +1022,10 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
                      card_serial_number)
         raise RuntimeError(msg)
 
-    def get_metadata_port_network(self, network):
+    def get_metadata_port(self, datapath_uuid):
         # TODO(twilson) This function should really just take a Row/RowView
         try:
-            dp = self.lookup('Datapath_Binding', uuid.UUID(network))
+            dp = self.lookup('Datapath_Binding', uuid.UUID(datapath_uuid))
         except idlutils.RowNotFound:
             return None
         cmd = self.db_find_rows('Port_Binding', ('datapath', '=', dp),
@@ -1026,9 +1086,8 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
             return [r for r in rows
                     if r.chassis and r.chassis[0].name == chassis or
                     chassis in [ch.name for ch in r.additional_chassis]]
-        else:
-            return [r for r in rows
-                    if r.chassis and r.chassis[0].name == chassis]
+        return [r for r in rows
+                if r.chassis and r.chassis[0].name == chassis]
 
     def get_chassis_host_for_port(self, port_id):
         chassis = set()
