@@ -14,6 +14,9 @@
 #    under the License.
 
 from neutron_lib.api.definitions import logging
+from neutron_lib.callbacks import events
+from neutron_lib.callbacks import registry
+from neutron_lib.callbacks import resources
 from neutron_lib.db import api as db_api
 from neutron_lib.services.logapi import constants as log_const
 
@@ -21,11 +24,13 @@ from neutron.db import db_base_plugin_common
 from neutron.extensions import logging as log_ext
 from neutron.objects import base as base_obj
 from neutron.objects.logapi import logging_resource as log_object
+from neutron.services.logapi.common import db_api as log_db_api
 from neutron.services.logapi.common import exceptions as log_exc
 from neutron.services.logapi.common import validators
 from neutron.services.logapi.drivers import manager as driver_mgr
 
 
+@registry.has_registry_receivers
 class LoggingPlugin(log_ext.LoggingPluginBase):
     """Implementation of the Neutron logging api plugin."""
 
@@ -36,7 +41,7 @@ class LoggingPlugin(log_ext.LoggingPluginBase):
     __filter_validation_support = True
 
     def __init__(self):
-        super(LoggingPlugin, self).__init__()
+        super().__init__()
         self.driver_manager = driver_mgr.LoggingServiceDriverManager()
         self.validator_mgr = validators.ResourceValidateRequest.get_instance()
 
@@ -45,6 +50,27 @@ class LoggingPlugin(log_ext.LoggingPluginBase):
         # supported_logging_types are be dynamically loaded from log_drivers
         return self.driver_manager.supported_logging_types
 
+    def start_rpc_listeners(self):
+        return self.driver_manager._start_rpc_listeners()
+
+    def _clean_logs(self, context, sg_id=None, port_id=None):
+        with db_api.CONTEXT_WRITER.using(context):
+            sg_logs = log_db_api.get_logs_bound_sg(
+                context, sg_id=sg_id, port_id=port_id, exclusive=True)
+            for log in sg_logs:
+                self.delete_log(context, log['id'])
+
+    @registry.receives(resources.SECURITY_GROUP, [events.AFTER_DELETE])
+    def _clean_logs_by_resource_id(self, resource, event, trigger, payload):
+        # log.resource_id == SG
+        self._clean_logs(payload.context.elevated(), sg_id=payload.resource_id)
+
+    @registry.receives(resources.PORT, [events.AFTER_DELETE])
+    def _clean_logs_by_target_id(self, resource, event, trigger, payload):
+        # log.target_id == port
+        self._clean_logs(payload.context.elevated(),
+                         port_id=payload.resource_id)
+
     @db_base_plugin_common.filter_fields
     @db_base_plugin_common.convert_result_to_dict
     def get_logs(self, context, filters=None, fields=None, sorts=None,
