@@ -99,7 +99,7 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
     __filter_validation_support = True
 
     def __init__(self):
-        super(PortForwardingPlugin, self).__init__()
+        super().__init__()
         self.push_api = resources_rpc.ResourcesPushRpcApi() \
             if self._rpc_notifications_required else None
         self.l3_plugin = directory.get_plugin(constants.L3)
@@ -311,9 +311,9 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                     "not suitable for internal neutron port "
                     "%(internal_port_id)s, as its fixed_ips are "
                     "%(fixed_ips)s") % {
-                    'internal_ip_address': internal_ip_address,
-                    'internal_port_id': internal_port['id'],
-                    'fixed_ips': v4_fixed_ips}
+                        'internal_ip_address': internal_ip_address,
+                        'internal_port_id': internal_port['id'],
+                        'fixed_ips': v4_fixed_ips}
                 raise lib_exc.BadRequest(resource=apidef.RESOURCE_NAME,
                                          msg=message)
 
@@ -329,10 +329,10 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                 "subnet %(internal_subnet_id)s. Cannot set "
                 "Port forwarding for port %(internal_port_id)s with "
                 "Floating IP %(port_forwarding_id)s") % {
-                'external_net_id': external_network_id,
-                'internal_subnet_id': internal_subnet_id,
-                'internal_port_id': internal_port_id,
-                'port_forwarding_id': fip_obj.id}
+                    'external_net_id': external_network_id,
+                    'internal_subnet_id': internal_subnet_id,
+                    'internal_port_id': internal_port_id,
+                    'port_forwarding_id': fip_obj.id}
             raise lib_exc.BadRequest(resource=apidef.RESOURCE_NAME,
                                      msg=message)
 
@@ -386,7 +386,7 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
             except obj_exc.NeutronDbObjectDuplicateEntry:
                 (__,
                  conflict_params) = self._find_existing_port_forwarding(
-                    context, floatingip_id, port_forwarding)
+                     context, floatingip_id, port_forwarding)
                 message = _("A duplicate port forwarding entry with same "
                             "attributes already exists, conflicting "
                             "values are %s") % conflict_params
@@ -434,11 +434,12 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                 internal_port = port_forwarding.get('internal_port')
                 if any([internal_ip_address, internal_port]):
                     port_forwarding.update({
-                        'internal_ip_address': internal_ip_address
-                        if internal_ip_address else
-                        str(pf_obj.internal_ip_address),
-                        'internal_port': internal_port if internal_port else
-                        pf_obj.internal_port
+                        'internal_ip_address':
+                            internal_ip_address if internal_ip_address else
+                            str(pf_obj.internal_ip_address),
+                        'internal_port':
+                            internal_port if internal_port else
+                            pf_obj.internal_port
                     })
                 pf_obj.update_fields(port_forwarding, reset_changes=True)
                 self._check_port_forwarding_update(context, pf_obj)
@@ -492,13 +493,13 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                                protocol=None, internal_ip_address=None):
         external_range_pf_dict = pf_dict.get('external_port_range')
         if not external_range_pf_dict and 'external_port' in pf_dict:
-            external_range_pf_dict = '%(port)s:%(port)s' % {
-                'port': pf_dict.get('external_port')}
+            external_range_pf_dict = '{port}:{port}'.format(
+                port=pf_dict.get('external_port'))
 
         internal_range_pf_dict = pf_dict.get('internal_port_range')
         if not internal_range_pf_dict and 'internal_port' in pf_dict:
-            internal_range_pf_dict = '%(port)s:%(port)s' % {
-                'port': pf_dict.get('internal_port')}
+            internal_range_pf_dict = '{port}:{port}'.format(
+                port=pf_dict.get('internal_port'))
 
         internal_port_id = pf_dict.get('internal_port_id') or internal_port_id
         protocol = pf_dict.get('protocol') or protocol
@@ -556,7 +557,7 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
         range_b = list(map(int, str(range_b).split(':')))
 
         invalid_port = next((port for port in (range_a + range_b)
-                             if 65535 < port or port < 1), None)
+                             if port > 65535 or port < 1), None)
 
         if invalid_port:
             raise lib_exc.BadRequest(resource=apidef.RESOURCE_NAME,
@@ -580,16 +581,17 @@ class PortForwardingPlugin(fip_pf.PortForwardingPluginBase):
                             "internal_ip_address: %(internal_ip_address)s, "
                             "internal_port: %(internal_port)s "
                             "already exists") % {
-                    'floatingip_id': fip_obj.id,
-                    'internal_ip_address': pf_dict['internal_ip_address'],
-                    'internal_port': pf_dict['internal_port']}
+                                'floatingip_id': fip_obj.id,
+                                'internal_ip_address':
+                                    pf_dict['internal_ip_address'],
+                                'internal_port': pf_dict['internal_port']}
             else:
                 message = _("The Floating IP %(floatingip_id)s had been set "
                             "on router %(router_id)s, the internal Neutron "
                             "port %(internal_port_id)s can not reach it") % {
-                    'floatingip_id': fip_obj.id,
-                    'router_id': fip_obj.router_id,
-                    'internal_port_id': internal_port_id}
+                                'floatingip_id': fip_obj.id,
+                                'router_id': fip_obj.router_id,
+                                'internal_port_id': internal_port_id}
             raise lib_exc.BadRequest(resource=apidef.RESOURCE_NAME,
                                      msg=message)
 
