@@ -68,11 +68,15 @@ class TestOVNClientPlacementExtension(base.TestOVNFunctionalBase):
         super().setUp(maintenance_worker=maintenance_worker,
                       service_plugins=service_plugins)
         self.ovn_client = self.mech_driver._ovn_client
-        self.placement_ext = self.ovn_client.placement_extension
+        self.ovn_client.placement_extension._reset(self.ovn_client)
         self.mock_name2uuid = mock.patch.object(
-            self.placement_ext, 'name2uuid').start()
+            self.ovn_client.placement_extension, 'name2uuid').start()
         self.mock_send_batch = mock.patch.object(
             placement_extension, '_send_deferred_batch').start()
+        self.addCleanup(self._reset_placement_singleton)
+
+    def _reset_placement_singleton(self):
+        del self.ovn_client.placement_extension
 
     def _build_other_config(self, bandwidths, inventory_defaults, hypervisors):
         options = []
@@ -105,7 +109,8 @@ class TestOVNClientPlacementExtension(base.TestOVNFunctionalBase):
 
         def check_chassis():
             nonlocal current_chassis
-            current_chassis = self.placement_ext.get_chassis_config()
+            current_chassis = (
+                self.ovn_client.placement_extension.get_chassis_config())
             current_chassis = {
                 chassis_name: placement_extension.dict_chassis_config(state)
                 for chassis_name, state in current_chassis.items()}
@@ -223,3 +228,34 @@ class TestOVNClientPlacementExtension(base.TestOVNFunctionalBase):
                           common_utils.wait_until_true,
                           lambda: mock_send_placement.called,
                           timeout=2)
+
+    @mock.patch.object(placement_extension, '_send_deferred_batch')
+    def test_chassis_bandwidth_initial_config_event(self, mock_send_placement):
+        ch_name = uuidutils.generate_uuid()
+        rp_uuid = uuidutils.generate_uuid()
+        ch_event = test_ovsdb_monitor.WaitForChassisPrivateCreateEvent(ch_name)
+        self.mech_driver.sb_ovn.idl.notify_handler.watch_event(ch_event)
+        self.mock_name2uuid.return_value = {'host1': rp_uuid}
+        self._create_chassis(
+            'host1', ch_name, physical_nets=['phys1'],
+            bandwidths='br-provider0:1000:2000',
+            inventory_defaults='allocation_ratio:1.0;min_unit:2',
+            hypervisors='br-provider0:host1')
+        self.assertTrue(ch_event.wait())
+        common_utils.wait_until_true(lambda: mock_send_placement.called,
+                                     timeout=2)
+        mock_send_placement.assert_called_once()
+        placement_state = mock_send_placement.call_args[0][0]
+
+        device_mappings = {'phys1': ['br-provider0']}
+        self.assertEqual(placement_state._device_mappings, device_mappings)
+
+        hypervisor_rps = {'br-provider0': {'name': 'host1', 'uuid': rp_uuid}}
+        self.assertEqual(placement_state._hypervisor_rps, hypervisor_rps)
+
+        rp_bandwidths = {'br-provider0': {'egress': 1000, 'ingress': 2000}}
+        self.assertEqual(placement_state._rp_bandwidths, rp_bandwidths)
+
+        rp_inventory_defaults = {'allocation_ratio': 1.0, 'min_unit': 2}
+        self.assertEqual(placement_state._rp_inventory_defaults,
+                         rp_inventory_defaults)
