@@ -40,21 +40,21 @@ class BaseChild(interface.LinuxInterfaceDriver):
         pass
 
 
-class FakeNetwork(object):
+class FakeNetwork:
     id = '12345678-1234-5678-90ab-ba0987654321'
 
 
-class FakeSubnet(object):
+class FakeSubnet:
     cidr = '192.168.1.1/24'
 
 
-class FakeAllocation(object):
+class FakeAllocation:
     subnet = FakeSubnet()
     ip_address = '192.168.1.2'
     ip_version = constants.IP_VERSION_4
 
 
-class FakePort(object):
+class FakePort:
     id = 'abcdef01-1234-5678-90ab-ba0987654321'
     fixed_ips = [FakeAllocation]
     device_id = 'cccccccc-cccc-cccc-cccc-cccccccccccc'
@@ -64,7 +64,7 @@ class FakePort(object):
 
 class TestBase(base.BaseTestCase):
     def setUp(self):
-        super(TestBase, self).setUp()
+        super().setUp()
         self.conf = config.setup_conf()
         ovs_conf.register_ovs_opts(self.conf)
         config.register_interface_opts(self.conf)
@@ -85,7 +85,7 @@ class TestBase(base.BaseTestCase):
 
 class TestABCDriver(TestBase):
     def setUp(self):
-        super(TestABCDriver, self).setUp()
+        super().setUp()
         mock_link_addr = mock.PropertyMock(return_value='aa:bb:cc:dd:ee:ff')
         type(self.ip_dev().link).address = mock_link_addr
 
@@ -204,7 +204,7 @@ class TestABCDriver(TestBase):
         ns = '12345678-1234-5678-90ab-ba0987654321'
         new_cidrs = ['192.168.1.2/24', '2001:db8:a::124/64']
         bc.init_router_port('tap0', new_cidrs, namespace=ns,
-            extra_subnets=[{'cidr': '172.20.0.0/24'}])
+                            extra_subnets=[{'cidr': '172.20.0.0/24'}])
         self.ip_dev.assert_has_calls(
             [mock.call('tap0', namespace=ns),
              mock.call().addr.list(),
@@ -476,11 +476,11 @@ class TestOVSInterfaceDriver(TestBase):
                 expected.extend(
                     [mock.call().ensure_namespace(namespace),
                      mock.call().ensure_namespace().add_device_to_namespace(
-                         mock.ANY, is_ovs_port=True),
+                         mock.ANY),
                      mock.call().ensure_namespace().add_device_to_namespace(
-                         mock.ANY, is_ovs_port=True),
+                         mock.ANY),
                      mock.call().ensure_namespace().add_device_to_namespace(
-                         mock.ANY, is_ovs_port=True)])
+                         mock.ANY)])
             expected.extend([
                 mock.call(namespace=namespace),
                 mock.call().device('tap0'),
@@ -544,7 +544,7 @@ class TestOVSInterfaceDriver(TestBase):
 class TestOVSInterfaceDriverWithVeth(TestOVSInterfaceDriver):
 
     def setUp(self):
-        super(TestOVSInterfaceDriverWithVeth, self).setUp()
+        super().setUp()
         ovs_conf.register_ovs_agent_opts(self.conf)
         self.conf.set_override('ovs_use_veth', True)
         self.conf.set_override(
@@ -631,79 +631,3 @@ class TestOVSInterfaceDriverWithVeth(TestOVSInterfaceDriver):
                                      mock.call().delete_port('tap0')])
         self.ip_dev.assert_has_calls([mock.call('ns-0', namespace=None),
                                       mock.call().link.delete()])
-
-
-class TestBridgeInterfaceDriver(TestBase):
-    def test_get_device_name(self):
-        br = interface.BridgeInterfaceDriver(self.conf)
-        device_name = br.get_device_name(FakePort())
-        self.assertEqual('ns-abcdef01-12', device_name)
-
-    def test_plug_no_ns(self):
-        self._test_plug()
-
-    def test_plug_with_ns(self):
-        self._test_plug(namespace='01234567-1234-1234-99')
-
-    def _test_plug(self, namespace=None):
-        def device_exists(device, namespace=None):
-            return device.startswith('brq')
-
-        root_veth = mock.Mock()
-        ns_veth = mock.Mock()
-
-        self.ip().add_veth = mock.Mock(return_value=(root_veth, ns_veth))
-        mock.patch.object(
-            interface, '_get_veth',
-            return_value=(root_veth, ns_veth)).start()
-
-        self.device_exists.side_effect = device_exists
-        br = interface.BridgeInterfaceDriver(self.conf)
-        mac_address = 'aa:bb:cc:dd:ee:ff'
-        br.plug('01234567-1234-1234-99',
-                'port-1234',
-                'ns-0',
-                mac_address,
-                namespace=namespace,
-                mtu=9000)
-
-        ip_calls = [mock.call(),
-                    mock.call().add_veth('tap0', 'ns-0', namespace2=namespace)]
-        ns_veth.assert_has_calls([mock.call.link.set_address(mac_address)])
-        ns_veth.assert_has_calls([mock.call.link.set_mtu(9000)])
-        root_veth.assert_has_calls([mock.call.link.set_mtu(9000)])
-
-        self.ip.assert_has_calls(ip_calls)
-
-        root_veth.assert_has_calls([mock.call.link.set_up()])
-        ns_veth.assert_has_calls([mock.call.link.set_up()])
-
-    def test_plug_dev_exists(self):
-        self.device_exists.return_value = True
-        with mock.patch('neutron.agent.linux.interface.LOG.info') as log:
-            br = interface.BridgeInterfaceDriver(self.conf)
-            br.plug('01234567-1234-1234-99',
-                    'port-1234',
-                    'tap0',
-                    'aa:bb:cc:dd:ee:ff')
-            self.assertFalse(self.ip_dev.called)
-            self.assertEqual(log.call_count, 1)
-
-    def test_unplug_no_device(self):
-        self.device_exists.return_value = False
-        self.ip_dev().link.delete.side_effect = RuntimeError
-        with mock.patch('neutron.agent.linux.interface.LOG') as log:
-            br = interface.BridgeInterfaceDriver(self.conf)
-            br.unplug('tap0')
-            [mock.call(), mock.call('tap0'), mock.call().link.delete()]
-            self.assertEqual(log.error.call_count, 1)
-
-    def test_unplug(self):
-        self.device_exists.return_value = True
-        with mock.patch('neutron.agent.linux.interface.LOG.debug') as log:
-            br = interface.BridgeInterfaceDriver(self.conf)
-            br.unplug('tap0')
-            self.assertEqual(log.call_count, 1)
-
-        self.ip_dev.assert_has_calls([mock.call('tap0', namespace=None),
-                                      mock.call().link.delete()])
